*********************************************************************************************************************
* FILE: P-VALUE ADJUSTENT
/********************************************************************************************************************
Project: Industrial Labor in Ethiopia (ILE)
Files Used: Data/ILEanalysis.dta
*********************************************************************************************************************/

/* CONTENT **********************************************
		
************************************************************/		

/* Note: This do file takes a different seed every time it runs, so it is not possible 
to exactly replicate the p-values in the paper, but you should get similar p-values */

// 1. DIRECTORY INFORMATION //

	//a. Open dataset

		use "$ILEdata/ILEanalysis.dta", clear
		
		
// 2. OUTCOMES AND BASELINE CONTROLS //
		
	//a. Baseline controls
	# delimit ;
		gl baseline "exactage_p99_b female_b
					single_b head_b disabled_b
					educ_p99_b cog_overall_index_b
					mentalhealth_index_b consc_std_b
					riskaversion_all_b patience_all_b  
					success_index_b 
					formal_expery_b
					factory_b
					optimism_index_b";
		gl baseline_larger "exactage_p99_b female_b
					single_b r_muslim_b hhsize_b head_b  dep_worker_p99_b educ_p99_b executive_score_b
					totalprofit7_av_p99_b consdur_p99_std_b factory_b 
					hourswork_wk_p99_b nowork_4weeks_b
					incdiff12_permon_p99_b borr3000bus_p99_b healthproblems_p99_b  disabled_b
					riskaversion_all_b patience_all_b locuscontrol_p99_std_b selfesteem_p99_std_b 
					famsupport_std_b commsupport_std_b  
					stat_change1_b phqtotal_r_std_b gadtotal_r_std_b agression_std_b consc_std_b fac_expery_b shop_expery_b statengo_expery_b
					prob_betterjob_b prob_regwork_b";
	# delimit cr
		/* Set control categories */
		gl demo "exactage_p99_b age2_p99_b age3_p99_b age4_p99_b female_b single_b r_muslim_b hhsize_b head_b dep_worker_p99_b"
		gl cog "all_math_p99_b educ_p99_b cognitive_score_b executive_score_b finsecondary_b"
		gl econ "totalprofit7_av_p99_b consdur_p99_std_b proddur_p99_std_b debttotal_p99_b save4weeks_p99_b"
		gl work "aghours_wk_p99_b cashours_wk_p99_b facthours_wk_p99_b pettybusnhours_wk_p99_b skilledhours_wk_p99_b wagelowhours_wk_p99_b wagemedhours_wk_p99_b othhours_wk_p99_b nowork_2weeks_b"
		gl exper "factory_b agexper_mo_p99_b casexper_mo_p99_b factexper_mo_p99_b pettybusnexper_mo_p99_b skilledexper_mo_p99_b wagelowexper_mo_p99_b wagemedexper_mo_p99_b othexper_mo_p99_b fac_expery_b shop_expery_b state_expery_b ngo_expery_b "
		gl optim "becomeill_b prob_betterjob_b prob_regwork_b mid12months_b incdiff30_b incdiff12_permon_p99_b"
		gl support "borr3000bus_p99_b famsupport_std_b commsupport_std_b"
		gl health "healthproblems_p99_b disabled_b stat_change1_b phqtotal_r_std_b gadtotal_r_std_b"
		gl personality "riskaversion_ibm_b riskaversion_p99_b patience_ibm_b timeinc_ibm_b patience_p99_b locuscontrol_p99_std_b selfesteem_p99_std_b selfcontrol_p99_std_b agression_std_b consc_std_b"
	
		gl controls "$demo $cog $econ $work $exper $optim $support $health $personality"
					
		gl controls_t5 "exactage_p99_b age2_p99_b age3_p99_b age4_p99_b single_b male_b r_muslim_b dep_worker_p99_b all_math_p99_b educ_p99_b totalprofit7_av_p99_std_b consdur_p99_std_b fac1_b hourswork_1w_b incdiff12_permon_p99_b save4weeks_p99_b borr3000bus_p99_b healthproblems_p99_b riskaversion_p99_b patience_p99_b locuscontrol_p99_b selfesteem_p99_b selfcontrol_p99_b finsecondary_b illit_b famsupport_b commsupport_b debttotal_p99_b stat_change1_b phqtotal_b gadtotal_b agression_b consc_b fac_expery_b shop_expery_b state_expery_b ngo_expery_b becomeill_b likely_betterjob_b likely_regwork_b mid12months_b incdiff30_b incdiff12_b translator_b"
		
	//b. Cohort dummies
		gl cohort "coh1 coh2 coh3 coh4 coh5 coh6 coh7 coh8" 
		gl blocks "coh1m coh2m coh3m coh4m coh5m coh6m coh7m coh8m coh1f coh2f coh3f coh4f coh5f coh6f coh7f coh8f"
		
	//c. Outcome Families

	# delimit ;	
		gl outcomes_Econ "employmentfamilyindex_e hourswork_wk_p99_e facthours_wk_p99_e aghourscom_wk_p99_e aghoursoth_wk_p99_e  
						pettybusnhours_wk_p99_e skilledhours_wk_p99_e cashours_wk_p99_e wagelowhours_wk_p99_e
						wagemedhours_wk_p99_e othhours_wk_p99_e nowork_dum_e hourswork_absdev_e hourswork_sqdev_e
						long_pmonth_e facfarm_e bigfac_pastmonth_e 
						bigfarmwage_pastmonth_e fulltimereg_e
						incomefamilyindex_e
						totalprofit7_av_p99_e totalprofit_h_av_p99_e totalprofit_absdev_e  totalprofit_sqdev_e cash4weeks_p99_e totalcash_absdev_e totalcash_sqdev_e 
						zeroprofit2w_e zerocash4w_e consdur_p99_std_e cons_month_p99_e proddur_p99_std_e
						healthrisks_e workcond_e migrated_e save4weeks_p99_e
						timeuse_commute_p99_e timeuse_leisure_p99_e timeuse_domestic_p99_e
						schooltrainnow_e currentschool_e tech_3m_e uni_3m_e";
		gl outcomes_HumanCapital "physhealthfamilyindex_e healthproblems_e disabled_e 
						health_laddnow_e health_laddyearago_e health_5years_e healthchange_lastyear_e healthchange_5years_e 
						menthealthfamilyindex_e phqtotal_r_e gadtotal_r_e
						anxiety_e  
						laddnow_e laddyearago_e ladd5years_e stat_change1_e stat_change3_e aggression_e";
		gl outcomes_Workplace "activityhome_e healthrisks_e
								airprob_e badsmell_e dust_e smokefire_e smokemachine_e badair_e
								workcond_e comfort_dum_e temperature_dum_e controlhours_dum_e timeoff_dum_e learnskills_dum_e space_dum_e shortbreaks_dum_e boring_dum_e"; 
		gl outcomes_Other "antifirmfamilyindex_e socintefamilyindex_e fempowerfamilyindex_e ncogskillsfamilyindex_e";
		gl outcomes_AppendixOther "antifirmfamilyindex_e firmsr_att_e foreignr_att_e unions_att_e workrights_per_e
							socintefamilyindex_e famsupport_e commsupport_e comminvolved_e trust_e
							fempowerfamilyindex_e femaleempower_e decision_e empowered_e abusein_e
							ncogskillsfamilyindex_e locuscontrol_e selfesteem_e patience_e 
							riskaversion_e selfcontrol_e punctual_e";
		gl outcomes_attitudes " rank_workerrights1_e rank2_firms3_e";
		gl outcomes_new "hourswork_e facthours_e aghourscom_e aghoursoth_e  
						pettybusnhours_e skilledhours_e cashours_e wagelowhours_e
						wagemedhours_e othhours_e
						income_y"; 

		gl outcomes_robustness "facfarm totalprofit7_av_p99 disabled stat_change1";
		gl outcomes_IndPerception "indperception_e r_enoughchores_e r_enoughtime_e r_enoughmoney_e 
						r_consultlargeexpense_e r_consultsmallexpense_e r_consultbigdecisions_e
						r_consultfirst_e r_respect_e r_valueopinionhh_e r_valueopinionpersonal_e singlehh_e";
		
	# delimit cr


// 3. RUN ADJUSTMENT //



* Begin program loop through each set of adjustments
# delimit ;
foreach y in  all {;
			
		* Variable list must be here to update properly when we add;
		* components that are only available for one endline term;
		local Y_main employmentfamilyindex  incomefamilyindex  physhealthfamilyindex menthealthfamilyindex ;
		local Y_all employmentfamilyindex  incomefamilyindex  physhealthfamilyindex menthealthfamilyindex antifirmfamilyindex socintefamilyindex fempowerfamilyindex ncogskillsfamilyindex;
			
		use "$ILEdata/ILEanalysis.dta", replace;

		* generate variables to store actual and simulated t-stats/p-vals ;
		local counter = 1;
		local g 0;
		gen str20 varname = "";
		gen str20 group = "";
		gen float tstat = .;
		gen float act_pval = .;
		gen float tstatsim = .;
		gen float pvalsim = .;
		gen float pvals = .;

		* run the original regressions for all of the different outcomes tested and store the actual (observed) p-vals/t-stats;
		foreach group in job ngo  {;
			local ++g;
			foreach lhsvar in  `Y_`y'' {;
				*qui reg `lhsvar'_e_av job ngo ${controls} ${blocks} i.round if round<=2 & found_av==1, robust;
				qui reg `lhsvar'_e job ngo ${blocks} ${controls} i.round if round<=3 & found == 1, robust cluster(appid);	
				quietly replace tstat = abs(_b[`group']/_se[`group']) in `counter';
				quietly replace act_pval = 2*ttail(e(N),abs(tstat)) in `counter';
				quietly replace varname = "`lhsvar'" in `counter';
				quietly replace group = "`group'" in `counter';
				local `lhsvar'_`g'_ct_0 = 0;
				local counter = `counter' + 1;
				};
			};

		* sort the p-vals by the actual (observed) p-vals (this will reorder some of the obs, but that shouldn't matter);
		gsort act_pval;
		local endvar = `counter' - 1;

		gen group_n = .;
		replace group_n=1 if group=="job";
		replace group_n=2 if group=="ngo";

		* generate the variable that will contain the simulated (placebo) treatments;
		gen byte sim_job = .;
		gen byte sim_ngo = .;
		gen float simtreatment_uni = .;
		local count = 1;
		local reps 1000;

		* run 1,000 iterations of the simulation, record results in p-val storage counters;
		while `count' <= `reps' {;
		* in this section we assign the placebo treatments and run regressions using the placebo treatments;
		* Since we are pooling, we need to be careful when reassigning treatment status;
			quietly replace simtreatment_uni = runiform() if round<=2;
			quietly replace sim_job = inrange(simtreatment_uni,0,.33) if round<=2;
			quietly replace sim_ngo = inrange(simtreatment_uni,.33,.67) if round<=2;
			
			foreach group in job ngo {;
				egen sim_`group'_max = mean(sim_`group'), by(appid);
				replace sim_`group' = sim_`group'_max if missing(sim_`group');
				drop sim_`group'_max;
			};
			
			quietly replace tstatsim = .;
			quietly replace pvalsim = .;
			foreach lhsvar of numlist 1/`endvar' {;
				local depvar = varname[`lhsvar'];
				local group = group[`lhsvar'];
				*qui reg `depvar'_e_av sim_job sim_ngo ${controls} ${blocks} i.round if round<=2 & found_av==1, robust;
				qui reg `depvar'_e sim_job sim_ngo ${blocks} ${controls} i.round if round<=3 & found == 1, robust cluster(appid);		
				quietly replace tstatsim = abs(_b[sim_`group']/_se[sim_`group']) in `lhsvar';
				quietly replace pvalsim = 2*ttail(e(N),abs(tstatsim)) in `lhsvar';
				};
		* in this section we perform the "step down" procedure that replaces simulated p-vals with the minimum of the set of simulated p-vals associated with outcomes that had actual p-vals greater than or equal to the one being replaced.  For each outcome, we keep count of how many times the ultimate simulated p-val is less than the actual observed p-val.;
			local countdown = `endvar';
			while `countdown' >= 1 {;
				quietly replace pvalsim = min(pvalsim,pvalsim[_n+1]) in `countdown';
				local depvar = varname[`countdown'];
				local group_n = group_n[`countdown'];
				if pvalsim[`countdown'] <= act_pval[`countdown'] {;
					local `depvar'_`group_n'_ct_0 = ``depvar'_`group_n'_ct_0' + 1;
					};
				local countdown = `countdown' - 1;
				}; 
			local count = `count' + 1;
			};

		* perform the final adjustment that ensures that the ordering to adjusted p-vals is the same as the original ordering of actual p-vals.;
		foreach lhsvar of numlist 1/`endvar' {;
			local depvar = varname[`lhsvar'];
			local group_n = group_n[`lhsvar'];
			quietly replace pvals = max(round(``depvar'_`group_n'_ct_0'/`reps',.001), pvals[`lhsvar'-1]) in `lhsvar';
			};

		sort group varname;
		keep if varname!="";
		keep varname group act_pval pvals;


save "$ILEWY\WY RI - appendix - `y'.dta", replace;
};
